# Change Log

## [v1.3](https://github.com/thewizardplusplus/white-generator/tree/v1.3) (2017-06-28)

**Closed issues:**

- Make a log colorful [\#15](https://github.com/thewizardplusplus/white-generator/issues/15)
- Process of the KeyboardInterrupt exception [\#16](https://github.com/thewizardplusplus/white-generator/issues/16)
- Use an uppercase in names of services files [\#18](https://github.com/thewizardplusplus/white-generator/issues/18)
- Prepare the package for a publication [\#20](https://github.com/thewizardplusplus/white-generator/issues/20)
- Correct the usage description [\#21](https://github.com/thewizardplusplus/white-generator/issues/21)
- Versions:
    - Specify a package version in the \_\_init\_\_.py file [\#12](https://github.com/thewizardplusplus/white-generator/issues/12)
    - Specify a minimal Python version in the setup.py file [\#13](https://github.com/thewizardplusplus/white-generator/issues/13)
    - Specify dependencies versions in the setup.py file [\#14](https://github.com/thewizardplusplus/white-generator/issues/14)
    - Refactor the version message [\#17](https://github.com/thewizardplusplus/white-generator/issues/17)
    - Automatically set a version number in the setup.py file [\#19](https://github.com/thewizardplusplus/white-generator/issues/19)

**Fixed bugs:**

- Use a context manager on a working with a database [\#22](https://github.com/thewizardplusplus/white-generator/issues/22)

## [v1.2](https://github.com/thewizardplusplus/white-generator/tree/v1.2) (2017-03-09)

**Closed issues:**

- Separate the code to some subpackages [\#9](https://github.com/thewizardplusplus/white-generator/issues/9)
- Add an installation via pip tool [\#7](https://github.com/thewizardplusplus/white-generator/issues/7)

**Fixed bugs:**

- Include a logging initialization into a try-except block [\#11](https://github.com/thewizardplusplus/white-generator/issues/11)
- Close a database connection [\#10](https://github.com/thewizardplusplus/white-generator/issues/10)
- Correct an exit code on an error [\#8](https://github.com/thewizardplusplus/white-generator/issues/8)

## [v1.1](https://github.com/thewizardplusplus/white-generator/tree/v1.1) (2017-02-15)

**Closed issues:**

- Fit a text into a specified rectangle [\#6](https://github.com/thewizardplusplus/white-generator/issues/6)
- Add text limits options [\#5](https://github.com/thewizardplusplus/white-generator/issues/5)
- Wrap a long text [\#4](https://github.com/thewizardplusplus/white-generator/issues/4)
- Add a support of an image background [\#3](https://github.com/thewizardplusplus/white-generator/issues/3)
- Add text align options [\#2](https://github.com/thewizardplusplus/white-generator/issues/2)
- Add text position options [\#1](https://github.com/thewizardplusplus/white-generator/issues/1)

## [v1.0](https://github.com/thewizardplusplus/white-generator/tree/v1.0) (2017-01-23)

*This change log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator).*
